[rtems commit] validation: Test object services

Sebastian Huber sebh at rtems.org
Thu Mar 24 10:01:58 UTC 2022


Module:    rtems
Branch:    master
Commit:    bc0cd6951e99a891e17fd39aa87f11d84fc93aa4
Changeset: http://git.rtems.org/rtems/commit/?id=bc0cd6951e99a891e17fd39aa87f11d84fc93aa4

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Thu Dec  9 16:19:24 2021 +0100

validation: Test object services

The test source code is generated from specification items
by the "./spec2modules.py" script contained in the
git://git.rtems.org/rtems-central.git Git repository.

Please read the "How-To" section in the "Software Requirements Engineering"
chapter of the RTEMS Software Engineering manual to get more information about
the process.

Update #3716.

---

 spec/build/testsuites/validation/validation-0.yml  |   1 -
 .../validation/validation-no-clock-0.yml           |   2 +
 testsuites/validation/tc-object.c                  |  56 +++++++++--
 testsuites/validation/tc-type.c                    | 103 +++++++++++++++++++++
 4 files changed, 154 insertions(+), 8 deletions(-)

diff --git a/spec/build/testsuites/validation/validation-0.yml b/spec/build/testsuites/validation/validation-0.yml
index c8e6d3b..1b14b1d 100644
--- a/spec/build/testsuites/validation/validation-0.yml
+++ b/spec/build/testsuites/validation/validation-0.yml
@@ -13,7 +13,6 @@ links: []
 source:
 - testsuites/validation/tc-acfg-appl-needs-clock-driver.c
 - testsuites/validation/tc-event-send-receive.c
-- testsuites/validation/tc-object.c
 - testsuites/validation/tr-event-send-receive.c
 - testsuites/validation/ts-validation-0.c
 stlib: []
diff --git a/spec/build/testsuites/validation/validation-no-clock-0.yml b/spec/build/testsuites/validation/validation-no-clock-0.yml
index a220a23..2edf12a 100644
--- a/spec/build/testsuites/validation/validation-no-clock-0.yml
+++ b/spec/build/testsuites/validation/validation-no-clock-0.yml
@@ -40,6 +40,7 @@ source:
 - testsuites/validation/tc-message-receive.c
 - testsuites/validation/tc-message-urgent-send.c
 - testsuites/validation/tc-modes.c
+- testsuites/validation/tc-object.c
 - testsuites/validation/tc-options.c
 - testsuites/validation/tc-part.c
 - testsuites/validation/tc-part-create.c
@@ -104,6 +105,7 @@ source:
 - testsuites/validation/tc-timer-reset.c
 - testsuites/validation/tc-timer-server-fire-after.c
 - testsuites/validation/tc-timer-server-fire-when.c
+- testsuites/validation/tc-type.c
 - testsuites/validation/tc-userext-create.c
 - testsuites/validation/tc-userext-delete.c
 - testsuites/validation/tc-userext-ident.c
diff --git a/testsuites/validation/tc-type.c b/testsuites/validation/tc-type.c
new file mode 100644
index 0000000..a190487
--- /dev/null
+++ b/testsuites/validation/tc-type.c
@@ -0,0 +1,103 @@
+/* SPDX-License-Identifier: BSD-2-Clause */
+
+/**
+ * @file
+ *
+ * @ingroup RTEMSTestCaseRtemsTypeValType
+ */
+
+/*
+ * Copyright (C) 2021 embedded brains GmbH (http://www.embedded-brains.de)
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ */
+
+/*
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
+ *
+ * https://www.rtems.org/bugs.html
+ *
+ * For information on updating and regenerating please refer to the How-To
+ * section in the Software Requirements Engineering chapter of the
+ * RTEMS Software Engineering manual.  The manual is provided as a part of
+ * a release.  For development sources please refer to the online
+ * documentation at:
+ *
+ * https://docs.rtems.org
+ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include <rtems.h>
+#include <rtems/score/objectimpl.h>
+
+#include <rtems/test.h>
+
+/**
+ * @defgroup RTEMSTestCaseRtemsTypeValType spec:/rtems/type/val/type
+ *
+ * @ingroup RTEMSTestSuiteTestsuitesValidationNoClock0
+ *
+ * @brief Tests some @ref RTEMSAPIClassicTypes interfaces.
+ *
+ * This test case performs the following actions:
+ *
+ * - Validate the RTEMS_ID_NONE constant.
+ *
+ *   - Assert that RTEMS_ID_NONE cannot be associated with an object because it
+ *     has an object index outside the range of valid object indices.
+ *
+ * @{
+ */
+
+/**
+ * @brief Validate the RTEMS_ID_NONE constant.
+ */
+static void RtemsTypeValType_Action_0( void )
+{
+  /* Nothing to do */
+
+  /*
+   * Assert that RTEMS_ID_NONE cannot be associated with an object because it
+   * has an object index outside the range of valid object indices.
+   */
+  RTEMS_STATIC_ASSERT(
+    ( ( RTEMS_ID_NONE >> OBJECTS_INDEX_START_BIT ) &
+      OBJECTS_INDEX_VALID_BITS ) < OBJECTS_INDEX_MINIMUM,
+    ID_NONE
+  );
+}
+
+/**
+ * @fn void T_case_body_RtemsTypeValType( void )
+ */
+T_TEST_CASE( RtemsTypeValType )
+{
+  RtemsTypeValType_Action_0();
+}
+
+/** @} */



More information about the vc mailing list
diff --git a/testsuites/validation/tc-object.c b/testsuites/validation/tc-object.c
index 916c35a..9e63d2a 100644
--- a/testsuites/validation/tc-object.c
+++ b/testsuites/validation/tc-object.c
@@ -59,22 +59,39 @@
 /**
  * @defgroup RTEMSTestCaseRtemsObjectValObject spec:/rtems/object/val/object
  *
- * @ingroup RTEMSTestSuiteTestsuitesValidation0
+ * @ingroup RTEMSTestSuiteTestsuitesValidationNoClock0
  *
- * @brief Tests the rtems_build_name() macro.
+ * @brief Tests some @ref RTEMSAPIClassicObject directives.
  *
  * This test case performs the following actions:
  *
  * - Validate the results of rtems_build_name() for a sample set of parameters.
  *
  *   - Check that the accumulated name has the expected value.
  *
+ * - Validate the result of rtems_object_get_local_node().
+ *
+ *   - Check that the returned value is one.
+ *
  * @{
  */
 
+static rtems_name BuildNameMacro( char c1, char c2, char c3, char c4 )
+{
+  return rtems_build_name( c1, c2, c3, c4 );
+}
+
+#undef rtems_build_name
+
+static rtems_name BuildName( char c1, char c2, char c3, char c4 )
+{
+  return rtems_build_name( c1, c2, c3, c4 );
+}
+
 /**
  * @brief Validate the results of rtems_build_name() for a sample set of
  *   parameters.
  */
 static void RtemsObjectValObject_Action_0( void )
 {
@@ -123,13 +140,22 @@ static void RtemsObjectValObject_Action_0( void )
           T_quiet_eq_u32( actual_name, expected_name )
           accumulated_name += actual_name;
 
-          actual_name = rtems_build_name(
+          actual_name = BuildName(
+            chars[ i ],
+            chars[ j ],
+            chars[ k ],
+            chars[ r ]
+          );
+          T_quiet_eq_u32( actual_name, expected_name );
+
+          actual_name = BuildNameMacro(
             chars[ i ],
             chars[ j ],
             chars[ k ],
             chars[ r ]
           );
           T_quiet_eq_u32( actual_name, expected_name );
+
           accumulated_name += actual_name;
         }
       }
@@ -143,13 +169,29 @@ static void RtemsObjectValObject_Action_0( void )
 }
 
 /**
+ * @brief Validate the result of rtems_object_get_local_node().
+ */
+static void RtemsObjectValObject_Action_1( void )
+{
+  uint32_t node;
+
+  node = rtems_object_get_local_node();
+
+  /*
+   * Check that the returned value is one.
+   */
+  T_step_eq_u32( 1, node, 1 );
+}
+
+/**
  * @fn void T_case_body_RtemsObjectValObject( void )
  */
 T_TEST_CASE( RtemsObjectValObject )
 {
-  T_plan( 1 );
+  T_plan( 2 );
 
   RtemsObjectValObject_Action_0();
+  RtemsObjectValObject_Action_1();
 }
 
 /** @} */
@@ -59,22 +59,39 @@
  * This test case performs the following actions:
  *
- * - Validate the results of rtems_build_name() for a sample set of parameters.
+ * - Validate the results of rtems_build_name() (function) and
+ *   rtems_build_name() (macro) for a sample set of parameters.
  *
  *   - Check that the accumulated name has the expected value.
@@ -59,22 +59,39 @@
 /**
- * @brief Validate the results of rtems_build_name() for a sample set of
- *   parameters.
+ * @brief Validate the results of rtems_build_name() (function) and
+ *   rtems_build_name() (macro) for a sample set of parameters.
  */
 static void RtemsObjectValObject_Action_0( void )